summaryrefslogtreecommitdiffstats
path: root/admin
diff options
context:
space:
mode:
Diffstat (limited to 'admin')
-rw-r--r--admin/kde.py24
1 files changed, 14 insertions, 10 deletions
diff --git a/admin/kde.py b/admin/kde.py
index 3a061ed..237a0c9 100644
--- a/admin/kde.py
+++ b/admin/kde.py
@@ -80,21 +80,21 @@ def detect_kde(env):
env.Exit(1)
env['QTDIR'] = qtdir.strip()
- ## Find the necessary programs uic and moc
- print "Checking for uic : ",
- uic = qtdir + "/bin/uic"
+ ## Find the necessary programs uic-tqt and moc
+ print "Checking for uic-tqt : ",
+ uic = qtdir + "/bin/uic-tqt"
if os.path.isfile(uic):
- print GREEN+"uic was found as "+uic+NORMAL
+ print GREEN+"uic-tqt was found as "+uic+NORMAL
else:
- uic = os.popen("which uic 2>/dev/null").read().strip()
+ uic = os.popen("which uic-tqt 2>/dev/null").read().strip()
if len(uic):
- print YELLOW+"uic was found as "+uic+NORMAL
+ print YELLOW+"uic-tqt was found as "+uic+NORMAL
else:
- uic = os.popen("which uic 2>/dev/null").read().strip()
+ uic = os.popen("which uic-tqt 2>/dev/null").read().strip()
if len(uic):
- print YELLOW+"uic was found as "+uic+NORMAL
+ print YELLOW+"uic-tqt was found as "+uic+NORMAL
else:
- print RED+"uic was not found - set QTDIR put it in your PATH ?"+NORMAL
+ print RED+"uic-tqt was not found - set QTDIR put it in your PATH ?"+NORMAL
env.Exit(1)
env['QT_UIC'] = uic
@@ -128,6 +128,10 @@ def detect_kde(env):
# Debian probably
print YELLOW+"the qt headers were found in /usr/include/qt3/ "+NORMAL
qtincludes = "/usr/include/qt3"
+ elif os.path.isfile("/usr/include/qt4/Qt/qglobal.h"):
+ # Debian probably
+ print YELLOW+"the qt headers were found in /usr/include/qt4/ "+NORMAL
+ qtincludes = "/usr/include/qt4"
else:
print RED+"the qt headers were not found"+NORMAL
env.Exit(1)
@@ -309,7 +313,7 @@ ie: """+BOLD+"""scons configure libdir=/usr/local/lib qtincludes=/usr/include/qt
env['QT_UIC_HFLAGS'] = '-L $QTPLUGINS -nounload'
env['QT_UIC_CFLAGS'] = '$QT_UIC_HFLAGS -tr tr2i18n'
- env['QT_LIBS'] = 'qt-mt'
+ env['QT_LIBS'] = 'tqt'
env['LIBTOOL_FLAGS'] = '--silent --mode=compile --tag=CXX'